# rumpy

Python SDK for [QuoRum](https://github.com/rumsystem/quorum).

### About QuoRum

- https://rumsystem.net/
- https://github.com/rumsystem/quorum/blob/main/Tutorial.md
- https://github.com/rumsystem/quorum

### Install

[rumpy@pypi](https://pypi.org/project/rumpy/)

```sh
pip install rumpy
```

### Env

init or update:

```sh
pip install pipenv
pipenv install
```

run:

```sh
pipenv shell
pipenv run python do_sth.py
```

### Examples

[>> Examples](https://github.com/liujuanjuan1984/rumpy/tree/master/examples)

### Contributing

- [>> Contributing](https://github.com/liujuanjuan1984/rumpy/tree/master/.github/CONTRIBUTING.md)
- [>> Bug Tracker](https://github.com/liujuanjuan1984/rumpy/issues/new)

### License

This work is released under the `GPL3.0` license. A copy of the license is provided in the [LICENSE](https://github.com/liujuanjuan1984/rumpy/blob/master/LICENSE) file.
